@@ -1,4 +1,4 @@
-package App::DistSync; # $Id: DistSync.pm 19 2014-10-18 16:56:35Z abalama $
+package App::DistSync; # $Id: DistSync.pm 22 2015-11-18 12:54:18Z abalama $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ App::DistSync - Utility synchronization of the mirror distribution-sites
 
 =head1 VERSION
 
-Version 1.01
+Version 1.03
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw/$VERSION/;
-$VERSION = '1.01';
+$VERSION = '1.03';
 
 use Carp;
 use File::Basename;
@@ -765,7 +765,10 @@ sub sync { # Synchronization. Main proccess
             last_pid    => $self->{pid},
             uri         => $self->{uri} || 'localhost',
             date        => scalar(localtime(time)),
-            status      => $status,
+            status      => 1, # $status,
+                            #  META        
+                            # .    -    .
+                            #   . #468
         };
     return 0 unless write_yaml($self->{file_meta}, $new_meta);
     
